@@ -7,13 +7,13 @@ PowrWorld's documentation for SimAuto can be found
 `here
 <https://www.powerworld.com/WebHelp/#MainDocumentation_HTML/Simulator_Automation_Server.htm%3FTocPath%3DAutomation%2520Server%2520Add-On%2520(SimAuto)%7C_____1>`__
 """
+import locale
 import logging
 import os
 from pathlib import Path, PureWindowsPath
 from typing import Union, List, Tuple
 import re
 import datetime
-import locale
 
 import numpy as np
 import pandas as pd
@@ -23,6 +23,10 @@ from win32com.client import VARIANT
 
 import tempfile
 
+# Before doing anything else, set up the locale. The docs note this is
+# not thread safe, and should thus be done right away.
+locale.setlocale(locale.LC_ALL, '')
+
 # TODO: Make logging more configurable.
 logging.basicConfig(
     format="%(asctime)s [%(levelname)s] [%(name)s]: %(message)s",
@@ -1416,7 +1420,9 @@ class SAW(object):
             contingency be obtained at a time.
         :param ObjFieldList: A list of strings which may contain plots,
             subplots, or individual object/field pairs specifying the
-            result variables to obtain.
+            result variables to obtain. For field name please check
+            `here <https://mzy2240.github.io/ESA/html/overview.html#powerworld-variables>`__.
+
         :param StartTime: The time in seconds in the simulation to begin
             retrieving results. If not specified (None), the start time
             of the simulation is used.
@@ -1832,6 +1838,11 @@ class SAW(object):
         :param errors: Passed directly to pandas.to_numeric, please
             consult the Pandas documentation. Available options at the
             time of writing are 'ignore', 'raise', and 'coerce'
+        :returns: data, but with all columns converted to numeric. Note
+            that if the errors parameter is 'ignore' that it's possible
+            not all data will be converted to numeric due to suppressed
+            errors. Also note that data which is already numeric will
+            remain unaltered.
         """
         # Determine if we're dealing with a DataFrame or Series.
         if isinstance(data, pd.DataFrame):
@@ -1849,13 +1860,12 @@ class SAW(object):
 
             if df_flag:
                 # Need to use apply to strip strings from multiple columns.
-                data = data.apply(lambda x:
-                                  x.str.replace(self.decimal_delimiter, '.'))
+                data = data.apply(self._replace_decimal_delimiter)
 
             else:
                 # A series is much simpler, and the .str.replace()
                 # method can be used directly.
-                data = data.str.replace(self.decimal_delimiter, '.')
+                data = self._replace_decimal_delimiter(data)
 
         # Convert to numeric and return.
         if df_flag:
@@ -1863,6 +1873,22 @@ class SAW(object):
         else:
             return data.apply(pd.to_numeric, errors=errors)
 
+    def _replace_decimal_delimiter(self, data: pd.Series):
+        """Helper to replace the decimal delimiter character with a
+        period. IMPORTANT NOTE: If the given Series does not have the
+        'str' attribute, this method assumes the data is already
+        numeric. the associated AttributeError will be ignored.
+
+        :param data: Pandas Series to replace self.decimal_delimiter
+            with a '.' character.
+        :returns: data, but with string replacement. If data does not
+            have the 'str' attribute, data is returned unmodified.
+        """
+        try:
+            return data.str.replace(self.decimal_delimiter, '.')
+        except AttributeError:
+            return data
+
 
 def convert_to_windows_path(p):
     """Given a path, p, convert it to a Windows path."""
